/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState, useEffect } from 'react'
import LoadingSpinner from '../../LoadingSpinner.js'
import TemplateCuradoria from '../PanelComponents/TemplateCuradoria.js'
import { getRequest } from '../../HelperFunctions/getAxiosConfig'

export default function TabPanelCuradoria(props) {
    const [loading, handleLoading] = useState(true)

    const [loadingMoreCurating, setLoadingMoreCurating] = useState(false)
    const [currLimitCurating, setcurrLimitCurating] = useState(4);
    const [endOfCurating, setEndofCurating] = useState(false);
    const [curating, setCurating] = useState([]);
    const [totalResults, setTotalResults] = useState(0);

    const showMoreCurating = (limite) => {
        setLoadingMoreCurating(true);
        const limit = limite;
        setcurrLimitCurating(currLimitCurating + limit)
        const url = `/users/${props.id}/submissions?offset=${currLimitCurating}&limit=${limit}&status=submitted`;
        getRequest(url,
            (data) => {
                if (data.length >= 1) {
                    let currData = [...curating];
                    currData = [...currData.concat(data)];
                    setLoadingMoreCurating(false);
                    setCurating([...currData]);
                }
                else {
                    setLoadingMoreCurating(false);
                    setEndofCurating(true);
                }

            },
            (error) => { console.log(error) }
        )
    }
    
    function handleSuccess(data, header) {
        if (header.has('X-Total-Count')) {
            setTotalResults(header.get('X-Total-Count'));
        }
        handleLoading(false)
        setCurating(data)
    }
    useEffect(() => {
        const url = `/users/${props.id}/submissions?offset=0&limit=4&status=submitted`
        handleLoading(true)
        getRequest(url, handleSuccess, (error) => { console.log(error) })
    }, [])

    return (
        <React.Fragment>
            {
                loading ?
                    (
                        <LoadingSpinner text={"Carregando Recursos"} />
                    )
                    :
                    (
                        [
                            <React.Fragment>
                                <TemplateCuradoria
                                    length={curating.length}
                                    titleText={curating.length === 1 ? "Recurso sendo avaliado pela curadoria" : "Recursos sendo avaliados pela curadoria"}
                                    noContentText={"Você não tem nenhum recurso sendo avaliado pelos curadores."}
                                    sliceArr={curating}
                                    showMore={showMoreCurating}
                                    loadingMore={loadingMoreCurating}
                                    end={endOfCurating}
                                    total={totalResults}
                                />
                            </React.Fragment>
                        ]
                    )
            }
        </React.Fragment>
    )
}
